@@ -4,7 +4,7 @@
 check.scalar.probability <- function(x) {
   okay <- is.numeric(x) && length(x) == 1 && x >= 0 && x <= 1
   if (!okay) {
-    stop("expected a scalar probability")
+    stop("Expected a scalar probability.")
   }
   return(TRUE)
 }
@@ -12,7 +12,15 @@ check.scalar.probability <- function(x) {
 check.positive.scalar <- function(x) {
   okay <- is.numeric(x) && length(x) == 1 && x > 0
   if (!okay) {
-    stop("expected a positive scalar")
+    stop("Expected a positive scalar.")
+  }
+  return(TRUE)
+}
+
+check.nonnegative.scalar <- function(x) {
+  okay <- is.numeric(x) && length(x) == 1 && x >= 0
+  if (!okay) {
+    stop("Expected a non-negative scalar.")
   }
   return(TRUE)
 }
@@ -20,14 +28,14 @@ check.positive.scalar <- function(x) {
 check.scalar.integer <- function(x) {
   okay <- is.numeric(x) && (length(x) == 1) && (abs(x - as.integer(x)) < 1e-10)
   if (!okay) {
-    stop("")
+    stop("Expected a scalar integer.")
   }
+  return(TRUE)
 }
 
-check.nonnegative.scalar <- function(x) {
-  okay <- is.numeric(x) && length(x) == 1 && x >= 0
-  if (!okay) {
-    stop("expected a non-negative scalar")
+check.scalar.boolean <- function(x) {
+  if (!is.logical(x) || !(length(x) == 1)) {
+    stop("Expected a scalar boolean value.")
   }
   return(TRUE)
 }
@@ -35,7 +43,8 @@ check.nonnegative.scalar <- function(x) {
 check.probability.distribution <- function(x) {
   okay <- is.numeric(x) && isTRUE(all.equal(sum(x), 1)) && all(x >= 0)
   if (!okay) {
-    stop("expected a discrete probability distribution")
+    stop("Expected a discrete probability distribution.")
   }
   return(TRUE)
 }
+
