@@ -65,7 +65,7 @@ namespace BOOM {
     virtual Vector::const_iterator unvectorize(Vector::const_iterator &v,
                                                bool minimal = true) = 0;
     virtual Vector::const_iterator unvectorize(const Vector &v,
-                                               bool minimal = true) = 0;
+                                               bool minimal = true);
   };
 
   //============================================================
@@ -92,8 +92,7 @@ namespace BOOM {
     Vector vectorize(bool minimal = true) const override;
     Vector::const_iterator unvectorize(Vector::const_iterator &v,
                                        bool minimal = true) override;
-    Vector::const_iterator unvectorize(const Vector &v,
-                                       bool minimal = true) override;
+    using Params::unvectorize;
   };
 
   //===========================================================================
@@ -149,9 +148,9 @@ namespace BOOM {
     Vector vectorize(bool minimal = true) const override;
     Vector::const_iterator unvectorize(Vector::const_iterator &v,
                                        bool minimal = true) override;
-    Vector::const_iterator unvectorize(const Vector &v,
-                                       bool minimal = true) override;
+    using Params::unvectorize;
   };
+
   //------------------------------------------------------------
   class MatrixParams : public MatrixData, virtual public Params {
    public:
@@ -164,8 +163,7 @@ namespace BOOM {
     Vector vectorize(bool minimal = true) const override;
     Vector::const_iterator unvectorize(Vector::const_iterator &v,
                                        bool minimal = true) override;
-    Vector::const_iterator unvectorize(const Vector &v,
-                                       bool minimal = true) override;
+    using Params::unvectorize;
   };
 
 }  // namespace BOOM
