@@ -22,9 +22,13 @@
 #include "Models/Glm/Glm.hpp"
 #include "Models/Glm/IndependentRegressionModels.hpp"
 #include "Models/StateSpace/Multivariate/StateModels/SharedStateModel.hpp"
+#include "Models/StateSpace/Multivariate/MultivariateStateSpaceRegressionDataPolicy.hpp"
+#include "Models/StateSpace/Multivariate/SharedStateModelManager.hpp"
+
 #include "Models/StateSpace/StateSpaceModel.hpp"
 #include "Models/StateSpace/StateModelVector.hpp"
 #include "Models/StateSpace/Multivariate/MultivariateStateSpaceModelBase.hpp"
+#include "Models/StateSpace/Multivariate/ProxyScalarStateSpaceModel.hpp"
 
 namespace BoomStateSpaceTesting{
   class MultivariateStateSpaceRegressionModelTest;
@@ -83,74 +87,6 @@ namespace BOOM {
     int timestamp_index_;
   };
 
-  //===========================================================================
-  // That MultivariateStateSpaceRegressionModel maintains a set of
-  // ScalarKalmanFilter objects to handle simulating from series-specific state.
-  // Each of these series-specific filters needs a "state space model" to supply
-  // the kalman matrices and data.  This class is a proxy state space model
-  // filling that role.  The proxy model keeps a pointer to the host model from
-  // which it draws data and parameters.  The proxy also assumes ownership of
-  // any series-specific state.
-  class MultivariateStateSpaceRegressionModel;
-  class ProxyScalarStateSpaceModel : public StateSpaceModel {
-   public:
-    // Args:
-    //   model:  The host model.
-    //   which_series: The index of the time series that this object describes.
-    ProxyScalarStateSpaceModel(MultivariateStateSpaceRegressionModel *model,
-                               int which_series);
-
-    // The number of distinct time points in the host model.
-    int time_dimension() const override;
-
-    // The value of the time series specific to this proxy.  The host should
-    // have subtracted any regression effects or shared state before this
-    // function is called.
-    double adjusted_observation(int t) const override;
-
-    bool is_missing_observation(int t) const override;
-
-    ZeroMeanGaussianModel *observation_model() override { return nullptr; }
-    const ZeroMeanGaussianModel *observation_model() const override {
-      return nullptr;
-    }
-
-    double observation_variance(int t) const override;
-
-    // Because the proxy model has no observation model,
-    // observe_data_given_state is a no-op.
-    void observe_data_given_state(int t) override {}
-
-    // Simulate 'horizon' time periods beyond time_dimension().
-    //
-    // Args:
-    //   rng: The [0, 1) random number generator to use for the simulation.
-    //   horizon: The number of periods beyond 'time_dimension()' to simulate.
-    //   final_state:  The value of the state at time time_dimension() - 1.
-    //
-    // Returns:
-    //   A draw from the predictive distribution of the state contribution over
-    //   the next 'horizon' time periods.
-    Vector simulate_state_contribution_forecast(
-        RNG &rng, int horizon, const Vector &final_state);
-
-    // Ensure all state models are capable of handling times up to t-1.
-    void observe_time_dimension(int t) {
-      for (int s = 0; s < number_of_state_models(); ++s) {
-        state_model(s)->observe_time_dimension(t);
-      }
-    }
-
-   private:
-    // The add_data method is disabled.
-    void add_data(const Ptr<StateSpace::MultiplexedDoubleData>
-                  &data_point) override;
-    void add_data(const Ptr<Data> &data_point) override;
-
-    MultivariateStateSpaceRegressionModel *host_;
-    int which_series_;
-  };
-
   //===========================================================================
   // A multivariate state space regression model describes a fixed dimensional
   // vector Y[t] as it moves throughout time.  The model is a state space model
@@ -200,11 +136,14 @@ namespace BOOM {
   // sampler class for IndependentRegressionModels.
   class MultivariateStateSpaceRegressionModel
       : public ConditionallyIndependentMultivariateStateSpaceModelBase,
-        public IID_DataPolicy<MultivariateTimeSeriesRegressionData>,
         public PriorPolicy
   {
     friend class BoomStateSpaceTesting::MultivariateStateSpaceRegressionModelTest;
    public:
+
+    using Proxy = ProxyScalarStateSpaceModel<
+     MultivariateStateSpaceRegressionModel>;
+
     // Args:
     //   xdim:  The dimension of the static regression component.
     //   nseries:  The number of time series being modeled.
@@ -266,41 +205,36 @@ namespace BOOM {
     //   series:  The index of the scalar time series described by the state.
     void add_series_specific_state(const Ptr<StateModel> &state_model,
                                    int series) {
-      proxy_models_[series]->add_state(state_model);
+      state_manager_.add_series_specific_state(state_model, series);
+      // proxy_models_[series]->add_state(state_model);
     }
 
     // Indicates whether any of the proxy models have had state assigned.
-    bool has_series_specific_state() const;
+    bool has_series_specific_state() const {
+      return state_manager_.has_series_specific_state();
+    }
 
     // Dimension of shared state.
     int state_dimension() const override {
-      return shared_state_models_.state_dimension();
+      return state_manager_.shared_state_dimension();
     }
 
     // The dimension of the series-specific state associated with a particular
     // time series.
     int series_state_dimension(int which_series) const {
-      if (proxy_models_.empty()) {
-        return 0;
-      } else {
-        return proxy_models_[which_series]->state_dimension();
-      }
+      return state_manager_.series_state_dimension(which_series);
     }
 
     int number_of_state_models() const override {
-      return shared_state_models_.size();
+      return state_manager_.number_of_shared_state_models();
     }
 
     SharedStateModel *state_model(int s) override {
-      if (s < 0 || s >= shared_state_models_.size()) {
-        return nullptr;
-      } else {
-        return shared_state_models_[s].get();
-      }
+      return state_manager_.shared_state_model(s);
     }
 
     const SharedStateModel *state_model(int s) const override {
-      return shared_state_models_[s].get();
+      return state_manager_.shared_state_model(s);
     }
 
     // Impute both the shared and series-specific state, each conditional on the
@@ -312,10 +246,12 @@ namespace BOOM {
     //-----------------------------------------------------------------------
 
     // The number of time points that have been observed.
-    int time_dimension() const override {return time_dimension_;}
+    int time_dimension() const override {
+      return data_policy_.time_dimension();
+    }
 
     // The number of time series being modeled.
-    int nseries() const override {return nseries_;}
+    int nseries() const override {return data_policy_.nseries();}
 
     // The dimension of the predictors.
     int xdim() const {return observation_model_->xdim();}
@@ -323,13 +259,17 @@ namespace BOOM {
     // Adding data to this model adjusts time_dimension_, data_indices_, and
     // observed_.
     void add_data(const Ptr<Data> &dp) override;
-    void add_data(const Ptr<MultivariateTimeSeriesRegressionData> &dp) override;
-    void add_data(MultivariateTimeSeriesRegressionData *dp) override;
+    void add_data(const Ptr<MultivariateTimeSeriesRegressionData> &dp);
+    void add_data(MultivariateTimeSeriesRegressionData *dp);
+
+    void combine_data(const Model &rhs, bool just_suf = true) override;
 
     // Return the position in the data vector containing the Y value for the
     // given series at the given time.  If no data point exists for the
     // requested (series, time) pair then -1 is returned.
-    int data_index(int series, int time) const;
+    int64_t data_index(int series, int time) const {
+      return data_policy_.data_index(series, time);
+    }
 
     // An override is needed so model-specific meta-data can be cleared as well.
     void clear_data() override;
@@ -340,28 +280,22 @@ namespace BOOM {
       if (index < 0) {
         return negative_infinity();
       } else {
-        return dat()[index]->y();
+        return data_policy_.data_point(series, time)->y();
       }
     }
 
     // A flag indicating whether a specific series was observed at time t.
     bool is_observed(int series, int time) const {
-      return observed_[time][series];
+      return data_policy_.observed(time)[series];
     }
 
     // Vector data access.
     ConstVectorView observation(int t) const override {
-      const Selector &observed(observed_[t]);
-      response_workspace_.resize(observed.nvars());
-      for (int i = 0; i < observed.nvars(); ++i) {
-        int series = observed.sparse_index(i);
-        response_workspace_[i] = response(series, t);
-      }
-      return ConstVectorView(response_workspace_);
+      return data_policy_.observation(t);
     }
 
     const Selector &observed_status(int t) const override {
-      return observed_[t];
+      return data_policy_.observed(t);
     }
 
     // Set the observation status for the data at time t.
@@ -381,13 +315,18 @@ namespace BOOM {
     // The vector of adjusted observations across all time series at time t.
     ConstVectorView adjusted_observation(int time) const override;
 
-    void isolate_shared_state() override;
-    void isolate_series_specific_state() override;
-
     //--------------------------------------------------------------------------
     // Kalman filter parameters.
     //--------------------------------------------------------------------------
 
+    void isolate_shared_state() override {
+      data_policy_.isolate_shared_state();
+    }
+
+    void isolate_series_specific_state() override {
+      data_policy_.isolate_series_specific_state();
+    }
+
     // The observation coefficients from the shared state portion of the model.
     // This does not include the regression coefficients from the regression
     // model, nor does it include the series-specific state.
@@ -398,17 +337,18 @@ namespace BOOM {
     DiagonalMatrix observation_variance(
         int t, const Selector &observed) const override;
 
+    Vector observation_variance_parameter_values() const override;
+
     double single_observation_variance(int t, int dim) const override {
       return observation_model_->model(dim)->sigsq();
     }
 
-    Ptr<ProxyScalarStateSpaceModel> series_specific_model(int index) {
-      return proxy_models_[index];
+    Proxy *series_specific_model(int index) {
+      return state_manager_.series_specific_model(index);
     }
 
-    const Ptr<ProxyScalarStateSpaceModel>
-    series_specific_model(int index) const {
-      return proxy_models_[index];
+    const Proxy *series_specific_model(int index) const {
+      return state_manager_.series_specific_model(index);
     }
 
     IndependentRegressionModels *observation_model() override {
@@ -430,21 +370,14 @@ namespace BOOM {
     Matrix state_contributions(int which_state_model) const override;
 
     StateSpaceUtils::StateModelVector<SharedStateModel>
-    &state_models() override { return shared_state_models_; }
+    &state_models() override { return state_manager_.shared_state_models(); }
 
     const StateSpaceUtils::StateModelVector<SharedStateModel>
-    &state_models() const override { return shared_state_models_; }
+    &state_models() const override { return state_manager_.shared_state_models(); }
 
     // Ensure that all state and proxy models are aware of times up to time 't'.
     void observe_time_dimension(int t) {
-      for (int s = 0; s < number_of_state_models(); ++s) {
-        state_model(s)->observe_time_dimension(t);
-      }
-      for (int m = 0; m < proxy_models_.size(); ++m) {
-        if (!!proxy_models_[m]) {
-          proxy_models_[m]->observe_time_dimension(t);
-        }
-      }
+      state_manager_.observe_time_dimension(t);
     }
 
     //------------- Parameter estimation by MLE and MAP --------------------
@@ -461,7 +394,7 @@ namespace BOOM {
     //
     // Returns:
     //   The value of the log-likelihood at the MLE.
-    double mle(double epsilon = 1e-5);
+    double mle(double epsilon = 1e-5, int ntries = 500) override;
 
     // Returns true if all the state models have been assigned priors that
     // implement find_posterior_mode.
@@ -586,9 +519,6 @@ namespace BOOM {
     using ConditionallyIndependentMultivariateStateSpaceModelBase::get_filter;
 
    private:
-    // Populate the vector of proxy models with 'nseries_' empty models.
-    void initialize_proxy_models();
-
     // Set observers on the variance parameters of the regression models, so
     // that the diagonal variance matrix can be updated when it gets out of
     // sync.
@@ -597,6 +527,11 @@ namespace BOOM {
     // Ditto for adjusted_data_workspace_.
     void set_workspace_observers();
 
+    // To be called during construction.  Set an observer on the parameters of
+    // *model that will invalidate the current kalman filter likelihood
+    // calculation when the parameters change.
+    void set_parameter_observers(Model *model);
+
     // If the observation variance is out of step with the observation_variance_
     // data member, update the data member.  This function is logically const.
     void update_observation_variance() const;
@@ -606,90 +541,21 @@ namespace BOOM {
     void observe_initial_state();
     void observe_data_given_state(int t) override;
 
-    //
-    void impute_missing_observations(int t, RNG &rng) override;
-
     void impute_shared_state_given_series_state(RNG &rng);
     void impute_series_state_given_shared_state(RNG &rng);
 
-    // Sets adjusted_data_workspace_ to observed_data minus contributions from
-    // series specific state.
-    // void isolate_shared_state();
-    void isolate_shared_state(int time) const;
-
-    // Sets adjusted_data_workspace_ to observed_data minus contributions from
-    // shared state.
-    //    void isolate_series_specific_state();
-    void isolate_series_specific_state(int time) const;
-
-    // The contribution of the series_specific state to the given series at the
-    // given time.
-    double series_specific_state_contribution(int series, int time) const;
-
     //--------------------------------------------------------------------------
     // Data section.
     //--------------------------------------------------------------------------
 
-    // The number of series being modeled.
-    int nseries_;
+    MultivariateStateSpaceRegressionDataPolicy<
+      MultivariateTimeSeriesRegressionData> data_policy_;
 
-    // The time dimension is the number of distinct time points.
-    int time_dimension_;
-
-    // The shared state models are stored in this container.  The series
-    // specific state models are stored in proxy_models_.
-    StateSpaceUtils::StateModelVector<SharedStateModel> shared_state_models_;
-
-    // The proxy models hold components of state that are specific to individual
-    // data series.
-    std::vector<Ptr<ProxyScalarStateSpaceModel>> proxy_models_;
-
-    // data_indices_[series][time] gives the index of the corresponding element
-    // of dat().
-    std::map<int, std::map<int, int>> data_indices_;
+    StateSpaceUtils::SharedStateModelManager<Proxy> state_manager_;
 
     // The observation model.
     Ptr<IndependentRegressionModels> observation_model_;
 
-    // mutable Ptr<StackedMatrixBlock> observation_coefficients_;
-
-    // The response matrix organizes all the scalar responses from each data
-    // point.  Time flows horizontally, so each column is a single time point.
-    mutable Vector response_workspace_;
-    //     mutable SelectorMatrix observed_;
-
-    // observed_[t] indicates which time series are observed at time t.
-    std::vector<Selector> observed_;
-
-    // A workspace where observed data can be modified by subtracting off
-    // components on which we wish to condition.
-    //
-    // The point of having this workspace, as opposed to simply making the
-    // adjustments on demand, is that the adjustments are best performed on a
-    // time-by-time basis, but the model also supports a (series, time)
-    // interface.  To make the latter more efficient we make adjustments on the
-    // time basis, store the results, and then look up the (series, time)
-    // answer.
-    mutable Vector adjusted_data_workspace_;
-
-    // Metadata about the adjusted_data_workspace_.
-    //
-    // A flag indicating that the workspace holds current values.  This is set
-    // to false whenever new parameters are assigned or new state is drawn.
-    mutable bool workspace_current_;
-
-    // The time index that the workspace currently describes.
-    mutable int workspace_time_index_;
-
-    // The type of information currently stored in the workspace.
-    enum WorkspaceStatus {
-      UNSET,
-      ISOLATE_SHARED_STATE,
-      ISOLATE_SERIES_SPECIFIC_STATE,
-      ISOLATE_REGRESSION_EFFECTS
-    };
-    mutable WorkspaceStatus workspace_status_;
-
     // A workspace to copy the residual variances stored in observation_model_
     // in the data structure expected by the model.
     mutable DiagonalMatrix observation_variance_;
