@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005 Steven L. Scott
 
@@ -20,14 +21,13 @@
 #define BOOM_RANDOM_ELEMENT
 
 #include <algorithm>
-#include <distributions.hpp>
-namespace BOOM{
+#include "distributions.hpp"
+namespace BOOM {
   template <class ForwardIt>
-  typename ForwardIt::reference
-  random_element(ForwardIt b, ForwardIt e){
-    uint N = std::distance(b,e);
-    uint n = random_int(0,N-1);
-    advance(b,n);
+  typename ForwardIt::reference random_element(ForwardIt b, ForwardIt e) {
+    uint N = std::distance(b, e);
+    uint n = random_int(0, N - 1);
+    advance(b, n);
     return *b;
   }
 
