@@ -38,13 +38,13 @@ namespace BOOM {
         --pos;
       }
       if (pos == start) pos = start + width;
-      if (start > 0 || (start == 0 && pad_first)) out << blanks;
+      if (start > 0 || pad_first) out << blanks;
       out << s.substr(start, pos - start) << "\n";
       start = pos + 1;
       while (start < back && s[start] == ' ') ++start;
     }
     if (back - start > 0) {
-      if (start > 0 || (start == 0 && pad_first)) out << blanks;
+      if (start > 0 || pad_first) out << blanks;
       out << s.substr(start, back - start) << "\n";
     }
     return out;
