@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
    Copyright (C) 2005 Steven L. Scott
 
@@ -13,18 +14,18 @@
 
    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
+   USA
  */
 
 #include <string>
-#include <cpputil/string_utils.hpp>
+#include "cpputil/string_utils.hpp"
 
-namespace BOOM{
+namespace BOOM {
   using std::string;
-  void legalize_file_name(string &s){
-    s = replace_all(s, " ","_");
-    s = replace_all(s, "/","-");
+  void legalize_file_name(string &s) {
+    s = replace_all(s, " ", "_");
+    s = replace_all(s, "/", "-");
     s = replace_all(s, ":", ".");
   }
-}
-
+}  // namespace BOOM
