@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
    Copyright (C) 2005 Steven L. Scott
 
@@ -13,22 +14,22 @@
 
    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
+   USA
  */
 
 #include <string>
- namespace BOOM{
-   using std::string;
-   string substring_delimited(string &s, char delim){
+namespace BOOM {
+  using std::string;
+  string substring_delimited(string &s, char delim) {
+    string::size_type n = s.find(delim);
+    if (n == string::npos) {
+      // delim was not found in string s
+      return s;
+    }
 
-     string::size_type n = s.find(delim);
-     if(n==string::npos){
-       // delim was not found in string s
-       return s;
-     }
-
-     string ans = s.substr(0,n);
-     s = s.substr(n+1);  // the +1 throws away the delimiter
-     return ans;
-   }
- }
+    string ans = s.substr(0, n);
+    s = s.substr(n + 1);  // the +1 throws away the delimiter
+    return ans;
+  }
+}  // namespace BOOM
